@@ -10,6 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from oslo.config import cfg
 
 from keystoneclient.auth import base
 
@@ -29,3 +30,25 @@ class Token(base.BaseAuthPlugin):
 
     def get_token(self, session):
         return self.token
+
+    def get_endpoint(self, session, **kwargs):
+        """Return the supplied endpoint.
+
+        Using this plugin the same endpoint is returned regardless of the
+        parameters passed to the plugin.
+        """
+        return self.endpoint
+
+    @classmethod
+    def get_options(cls):
+        options = super(Token, cls).get_options()
+
+        options.extend([
+            cfg.StrOpt('endpoint',
+                       help='The endpoint that will always be used'),
+            cfg.StrOpt('token',
+                       secret=True,
+                       help='The token that will always be used'),
+        ])
+
+        return options
