@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import httpretty
+from testtools import matchers
 
 from keystoneclient.auth import token_endpoint
 from keystoneclient import session
@@ -22,9 +22,8 @@ class TokenEndpointTest(utils.TestCase):
     TEST_TOKEN = 'aToken'
     TEST_URL = 'http://server/prefix'
 
-    @httpretty.activate
     def test_basic_case(self):
-        httpretty.register_uri(httpretty.GET, self.TEST_URL, body='body')
+        self.requests.register_uri('GET', self.TEST_URL, text='body')
 
         a = token_endpoint.Token(self.TEST_URL, self.TEST_TOKEN)
         s = session.Session(auth=a)
@@ -33,3 +32,24 @@ class TokenEndpointTest(utils.TestCase):
 
         self.assertEqual(data.text, 'body')
         self.assertRequestHeaderEqual('X-Auth-Token', self.TEST_TOKEN)
+
+    def test_basic_endpoint_case(self):
+        self.stub_url('GET', ['p'], text='body')
+        a = token_endpoint.Token(self.TEST_URL, self.TEST_TOKEN)
+        s = session.Session(auth=a)
+
+        data = s.get('/p',
+                     authenticated=True,
+                     endpoint_filter={'service': 'identity'})
+
+        self.assertEqual(self.TEST_URL, a.get_endpoint(s))
+        self.assertEqual('body', data.text)
+        self.assertRequestHeaderEqual('X-Auth-Token', self.TEST_TOKEN)
+
+    def test_token_endpoint_options(self):
+        opt_names = [opt.name for opt in token_endpoint.Token.get_options()]
+
+        self.assertThat(opt_names, matchers.HasLength(2))
+
+        self.assertIn('token', opt_names)
+        self.assertIn('endpoint', opt_names)
